* Retraitement base fiscale 2011

set more off
clear
set max_memory 12g

global year=2012



******************************************************************************************************************
* Legislative parameters converted in macro
		import excel using "$datarev/Parametres_IR.xls", first clear sheet("Parametres")  cellrange(A1:F20)
			foreach var of varlist tauxmicro_fon-tauxbnc{
				quiet sum `var' if year==$year
				global `var'=r(mean)
		}		
***************************************************************************************************************

use "$datarev/rev$year.dta",clear
foreach var of varlist _all {
	local j=upper("`var'")
	rename `var' `j'
}
gen year=$year

* Ponderation
	gen pondn=PONDV
* Caractristiques dmographiques
	* age
		gen age=year-AGED
		replace age=20 if age <20 | age==.
	* Nombre de dclarants dans la dclaration
		gen ndecl=2
		replace ndecl=1 if AGEC==9999
	* age du conjoint
		gen agec=year-AGEC if AGEC~=9999
		replace agec=20 if agec<20
	* sexe
		gen sexe=INDG
	* Structure demo des pac
			*dnpa4c : date de naissance et type de pac	
			gen npac=length(DNPA4C)/5
			quiet sum npac
			forval i=1/`r(max)' {
				local a= 2+5*(`i'-1)
				gen anaispac_`i'= year-real(substr(DNPA4C,`a' , 4 ))
				replace anaispac_`i'= year-real(substr(DNPA4C,`a' , 4 ))-2000 if substr(DNPA4C,`a' , 2 )=="00" & anaispac_`i'>=2000 & !missing(anaispac_`i') 
				replace anaispac_`i'= year-real(substr(DNPA4C,`a' , 4 ))-1900 if substr(DNPA4C,`a' , 2 )=="00" & anaispac_`i'<2000 & !missing(anaispac_`i') 
				replace anaispac_`i'= year-real(substr(DNPA4C,`a' , 4 ))-1000 if substr(DNPA4C,`a' , 2 )=="09"
			}
			
	* situation matrimoniale : O= pacs
		* A partir de 2006, code matrimonial passe de numrique  string. plus de retraitement  faire
		gen mat=MAT
	
	* Impot pay
		gen irtot=MNIRMM /* Impot immediat */
		gen irpv=MNIRVP /* impot pv taux propor */
		gen iravantpv=irtot-irpv
	
***********************************************************
*I)Traitements, salaires, pensions et rentes viagres  
***********************************************************
	foreach var of newlist sal_irpp chom_irpp frais_prof pension_irpp {
		gen `var'=0
		gen `var'_conj=0
		gen `var'_pac=0
	}

	* A) Salaires et chmages
	*************************
		* Distinction entre sal et chom  partir de 2002
		*A partir de 2007 : heures supplmentaires exonres
		replace sal_irpp=Z1AJ +Z1AU + Z1TY
		replace chom_irpp=Z1AP 

		replace sal_irpp_conj =  Z1BJ  +Z1BU+ Z1UY
		replace chom_irpp_conj = Z1BP 
		
		* Frais pro
		replace frais_prof=Z1AK
		replace frais_prof_conj=Z1BK

	* B) Retraite
	**************
		* A partir de 1999, AS correspond uniquement aux pensions de retraites.
		* Auparavant incluait aussi pensions alimentaires reues
		* Les pensions alimentaires perues ne sont pas pris en compte
			replace pension_irpp=Z1AS
			replace pension_irpp_conj=Z1BS
			
	* C) Rentes viageres 
	**********************
		gen rente_irpp_foy=0
		local liste A B C D 
		foreach x of local liste {
			replace rente_irpp_foy= rente_irpp_foy+Z1`x'W
		}
		replace rente_irpp_foy= rente_irpp_foy + Z1AT + Z1BT
		
	* D)Personne  charge PAC
	****************************
		local liste C D E F
		foreach x of local liste {
			replace sal_irpp_pac= sal_irpp_pac + Z1`x'J
			replace chom_irpp_pac= chom_irpp_pac + Z1`x'P 
			replace frais_prof_pac=frais_prof_pac + Z1`x'K
			replace pension_irpp_pac= pension_irpp_pac+ Z1`x'S
		}
		replace sal_irpp_pac=sal_irpp_pac+ Z1CU+Z1DU 
		
	* E) Au niveau foyer fiscal
	****************************
		gen sal_irpp_foy=sal_irpp+sal_irpp_conj+sal_irpp_pac
		gen chom_irpp_foy=chom_irpp+chom_irpp_conj+chom_irpp_pac
		gen frais_prof_foy=frais_prof+frais_prof_conj+frais_prof_pac
		gen pension_irpp_foy =pension_irpp+ pension_irpp_conj +pension_irpp_pac
		gen salchom_irpp_foy=sal_irpp_foy+ chom_irpp_foy
		drop Z1A* Z1B* Z1C* Z1D* Z1E* Z1F*
	
	
**************************************	
*II)  Revenus des capitaux mobiliers
**************************************	
		
		* A)Assurance-vie
		******************
			* Barme
				gen rfin_av_bar_irpp_foy = Z2CH
			* PL
				gen rfin_av_pl_irpp_foy= Z2DH
			* Total
				gen rfin_av_irpp_foy=rfin_av_bar_irpp_foy+rfin_av_pl_irpp_foy
		
		* B)Dividendes : 
		*****************
		* Changement par rapport  2009 : suppression de 2GR (revenus distribus dans le PEA)
			* Au barme 
				gen rfin_div_bar_irpp_foy = Z2DC +Z2FU 
			* Au PL  partir de 2008
				gen rfin_div_pl_irpp_foy=Z2DA
			* Total
				gen rfin_div_irpp_foy=rfin_div_pl_irpp_foy+rfin_div_bar_irpp_foy
		
			
		* C)Intrts 
		**************
			* Barme
				gen rfin_int_bar_irpp_foy= Z2TS + Z2GO+ Z2TR
			* PL report seulement  partir de 1999
				gen rfin_int_pl_irpp_foy= Z2EE
			* Total
				gen rfin_int_irpp_foy= rfin_int_bar_irpp_foy+ rfin_int_pl_irpp_foy
		
		* D) Totaux 
		**************
				gen rfin_pl_irpp_foy=rfin_av_pl_irpp_foy+rfin_div_pl_irpp_foy+rfin_int_pl_irpp_foy
				gen rfin_bar_irpp_foy=rfin_av_bar_irpp_foy+rfin_div_bar_irpp_foy+rfin_int_bar_irpp_foy
				gen rfin_irpp_foy=rfin_av_irpp_foy+rfin_div_irpp_foy+rfin_int_irpp_foy

			* Avant 2005, on remboursait l'IS prlev sur les dividendes via un avoir fiscal pour viter double imposition.
			* Systme a chang en 2005 en crant un abattement remplaant l'avoir fiscal
			

*******************************
*III) Revenus non salaris
*******************************
* Creation du statut jeune agriculteur et artisan pcheur en 2003.
* Creation du statut jeunes createurs  partir des revenus 2006.

* Pour ces deux catgories, les bnfices sont reports aprs dduction de l'abattement. Le montant de l'abattement utilis est ensuite report aux  cases "jeune agriculteur" et "artisan pcheur"
* Il faut donc rajouter le montant de l'abattement  aux revenus exonrs.
		
foreach var of newlist nonsal_irpp nonsalexo_irpp nonsal defnonsal_irpp microbic_vente microbic_serv microbnc {
		gen `var'=0
		gen `var'_conj=0
		gen `var'_pac=0
	}

		
		* A) Revenus non salaris exos
		*******************************
		* Prise en comptes de l'abattement jeune agri et artisan pecheur par rapport  2002
		* Creation abattement jeunes createurs  partir des revenus 2006.
		* Changement depuis 2008 : Introduction de 5TH UH VH : revenus xonr du rgime dclaratif spcial de la section E.
		* Changement par rapport  2010 : Introduction pour jeunes agri : 5HZ 5IZ et 5JZ	
			local liste H  K  N 
			foreach x of local liste {
				local liste2 N B H
				foreach y of local liste2 {
					replace nonsalexo_irpp=nonsalexo_irpp+Z5`x'`y'
				}
			}
			local liste  I  L  O 
			foreach x of local liste {
				local liste2 N B H
				foreach y of local liste2 {
					replace nonsalexo_irpp_conj=nonsalexo_irpp_conj+Z5`x'`y'
				}
			}
			local liste  J M P
			foreach x of local liste {
				local liste2 N B H
				foreach y of local liste2 {
					replace nonsalexo_irpp_pac=nonsalexo_irpp_pac+Z5`x'`y'
				}
			}
			
			local liste Q   
			foreach x of local liste {
				local liste2 B H L
				foreach y of local liste2 {
					replace nonsalexo_irpp=nonsalexo_irpp+Z5`x'`y'
				}
			}
			local liste  R  
			foreach x of local liste {
				local liste2 B H L
				foreach y of local liste2 {
					replace nonsalexo_irpp_conj=nonsalexo_irpp_conj+Z5`x'`y'
				}
			}
			local liste  S  
			foreach x of local liste {
				local liste2 B H L
				foreach y of local liste2 {
					replace nonsalexo_irpp_pac=nonsalexo_irpp_pac+Z5`x'`y'
				}
			}
			local liste H 
			foreach x of local liste {
				local liste2 P M Z
				foreach y of local liste2 {
					replace nonsalexo_irpp=nonsalexo_irpp+Z5`x'`y'
				}
			}
			local liste  I 
			foreach x of local liste {
				local liste2 P M Z
				foreach y of local liste2 {
					replace nonsalexo_irpp_conj=nonsalexo_irpp_conj+Z5`x'`y'
				}
			}
			local liste  J
			foreach x of local liste {
				local liste2 P M Z
				foreach y of local liste2 {
					replace nonsalexo_irpp_pac=nonsalexo_irpp_pac+Z5`x'`y'
				}
			}
			local liste K 
			foreach x of local liste {
				local liste2 S
				foreach y of local liste2 {
					replace nonsalexo_irpp=nonsalexo_irpp+Z5`x'`y'
				}
			}
			local liste  L 
			foreach x of local liste {
				local liste2 S
				foreach y of local liste2 {
					replace nonsalexo_irpp_conj=nonsalexo_irpp_conj+Z5`x'`y'
				}
			}
			local liste  M 
			foreach x of local liste {
				local liste2 S
				foreach y of local liste2 {
					replace nonsalexo_irpp_pac=nonsalexo_irpp_pac+Z5`x'`y'
				}
			}
			replace nonsalexo_irpp=nonsalexo_irpp+Z5SV + Z5TH
			replace nonsalexo_irpp_conj=nonsalexo_irpp_conj+Z5SW + Z5UH
			replace nonsalexo_irpp_pac=nonsalexo_irpp_pac+Z5SX + Z5VH
			
			replace nonsalexo_irpp=nonsalexo_irpp+Z5HK + Z5IK
			replace nonsalexo_irpp_conj=nonsalexo_irpp_conj+Z5JK + Z5KK
			replace nonsalexo_irpp_pac=nonsalexo_irpp_pac+Z5LK + Z5MK
		
			
		
		* B)Revenus non salaris: benefice
		**************************************
		* On rajoute 25% pour centre non agre
		*Changement par rapport  2009: 
				*Suppresion de KD LD MD KJ LJ MJ (rgime simplifi du rgime du bnfice rel, section B)
				*Suppression de ND OD PD NJ OJ PJ (rgime simplifi du rgime du bnfice rel, section C)
			
		*Changement par rapport  2012: 
				*Introduction de 5NM OM PM: revenus imposables (idem que NA OA PA)
				
			local liste H  
			foreach x of local liste {
				local liste2 O D C A
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+Z5`x'`y'
				}
				replace nonsal_irpp=nonsal_irpp+Z5`x'I*1.25
			}
			local liste I 
			foreach x of local liste {
				local liste2 O D C A
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+Z5`x'`y'
				}
				replace nonsal_irpp_conj=nonsal_irpp_conj+Z5`x'I*1.25
			}
			local liste J 
			foreach x of local liste {
				local liste2 O D C A
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+Z5`x'`y'
				}
				replace nonsal_irpp_pac=nonsal_irpp_pac+Z5`x'I*1.25
			}
				
			local liste K 
			foreach x of local liste {
				local liste2 C 
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+Z5`x'`y'
				}
				local liste2 I A
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+Z5`x'`y'*1.25
				}
			}
				
			local liste L  
			foreach x of local liste {
				local liste2 C 
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+Z5`x'`y'
				}
				local liste2 I A
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+Z5`x'`y'*1.25
				}
			}	
			local liste M 
			foreach x of local liste {
				local liste2 C 
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+Z5`x'`y'
				}
				local liste2 I A
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+Z5`x'`y'*1.25
				}
			}
			local liste N
			foreach x of local liste {
				local liste2 C  A  M
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+Z5`x'`y'
				}
				local liste2 I  K
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+Z5`x'`y'*1.25
				}
			}
					
			local liste O 
			foreach x of local liste {
				local liste2 C  A  M
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+Z5`x'`y'
				}
				local liste2 I  K
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+Z5`x'`y'*1.25
				}
			}
			local liste P
			foreach x of local liste {
				local liste2 C  A  M
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+Z5`x'`y'
				}
				local liste2 I  K
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+Z5`x'`y'*1.25
				}
			}
			
			local liste Q
			foreach x of local liste {
				local liste2 C
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+Z5`x'`y'
				}
				local liste2 I
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+Z5`x'`y'*1.25
				}
			}
			local liste R
			foreach x of local liste {
				local liste2 C
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+Z5`x'`y'
				}
				local liste2 I
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+Z5`x'`y'*1.25
				}
			}
			local liste S
			foreach x of local liste {
				local liste2 C
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+Z5`x'`y'
				}
				local liste2 I
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+Z5`x'`y'*1.25
				}
			}
			
			replace nonsal_irpp=nonsal_irpp+Z5SN*1.25+Z5KM*1.25
			replace nonsal_irpp_conj=nonsal_irpp_conj+Z5NS*1.25+Z5LM*1.25
			replace nonsal_irpp_pac=nonsal_irpp_pac+Z5OS*1.25+Z5MM*1.25
			replace nonsal_irpp=nonsal_irpp+Z5JG
			replace nonsal_irpp_conj=nonsal_irpp_conj+Z5RF
			replace nonsal_irpp_pac=nonsal_irpp_pac+Z5SF


		
		* C) Revenus non salairs: plus-values voir section plus-value rfin_pv_pro_irpp_foy
		***************************************************************************************	

		* D)Revenus non salaris: dficits
		***********************************		
		*Changement par rapport  2009: 
			*suppresion de KG KM LG LM MG MM (dficit du rgime sinplifi du rgime du bnfice rel, section B)
			*suppresion de NG NM OG OM PG PM (dficit du rgime sinplifi du rgime du bnfice rel, section B)
		
			local liste H  
			foreach x of local liste {
				local liste2 F L
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+Z5`x'`y'
				}
			}
			local liste I   
			foreach x of local liste {
				local liste2 F L
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+Z5`x'`y'
				}
			}
			local liste J  
			foreach x of local liste {
				local liste2 F L
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+Z5`x'`y'
				}
			}
			
			
			local liste K  
			foreach x of local liste {
				local liste2 F L 
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+Z5`x'`y'
				}
			}
			local liste L  
			foreach x of local liste {
				local liste2 F L 
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+Z5`x'`y'
				}
			}
			local liste M 
			foreach x of local liste {
				local liste2 F L 
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+Z5`x'`y'
				}
			}
					
			local liste Q
			foreach x of local liste {
				local liste2 A J E K
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+Z5`x'`y'
				}
			}		
			local liste R 
			foreach x of local liste {
				local liste2 A J E K
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+Z5`x'`y'
				}
			}		
			local liste S
			foreach x of local liste {
				local liste2 A J E K
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+Z5`x'`y'
				}
			}
			
			*replace defnonsal_irpp=defnonsal_irpp+Z5SJ
			* Note  SA non reports Dficits locations meubles rgime du bnfice rel
			local liste N
			foreach x of local liste {
				local liste2 F L Y Z 
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+Z5`x'`y'
				}
			}
			local liste O
			foreach x of local liste {
				local liste2 F L Y Z 
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+Z5`x'`y'
				}
			}
			local liste P
			foreach x of local liste {
				local liste2 F L Y Z 
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+Z5`x'`y'
				}
			}
			
			replace defnonsal_irpp=defnonsal_irpp+Z5SP
			replace defnonsal_irpp_conj=defnonsal_irpp_conj+Z5NU
			replace defnonsal_irpp_pac=defnonsal_irpp_pac+Z5OU
			replace defnonsal_irpp=defnonsal_irpp+Z5JJ
			replace defnonsal_irpp_conj=defnonsal_irpp_conj+Z5RG
			replace defnonsal_irpp_pac=defnonsal_irpp_pac+Z5SG
			
			
		* E)Revenus non salaris: micro-fonciers et auto-entrepreneurs
		*************************************************************
		* Recalcul du bnfice pour les auto-entrepreneurs et le rgime micro-entreprise (il faut dduire un abattement du chiffre d'affaire dclar pour retrouver le bnfice rel)
		*Changement par rapport  2009 : suppresion de 5(T,U,V)*(C,D,G) (versement libratoire pour autoentrepreneurs)
		*Changement par rapport  2010 :
			*Cration rgime microentreprise pour location meuble non professionnelle (5ND OD PD) : Prestation de services
			*Cration rgime microentreprise pour location gtes, chambres htes et meubls tourisme non professionnelle (5NG OG PG)) : Vente de marchandises				
		*Changement par rapport  2012 :
			*Introduction de 5NG OG PG: beneficient d un abbattement de 71% donc ce sont des BIC vente --> mis avec 5NG OG PG
		
		* Micro bic et autoentrepeneur : vente de marchandises
				local liste T
				foreach x of local liste {
					local liste2 A 
					foreach y of local liste2 {
						replace microbic_vente=microbic_vente+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
				local liste U 
				foreach x of local liste {
					local liste2 A 
					foreach y of local liste2 {
						replace microbic_vente_conj=microbic_vente_conj+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
				local liste V
				foreach x of local liste {
					local liste2 A 
					foreach y of local liste2 {
						replace microbic_vente_pac=microbic_vente_pac+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
				
				local liste K N 
				foreach x of local liste {
					local liste2 O 
					foreach y of local liste2 {
						replace microbic_vente=microbic_vente+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
				local liste L O 
				foreach x of local liste {
					local liste2 O 
					foreach y of local liste2 {
						replace microbic_vente_conj=microbic_vente_conj+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
				
				local liste M P
				foreach x of local liste {
					local liste2 O 
					foreach y of local liste2 {
						replace microbic_vente_pac=microbic_vente_pac+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
				
				local liste N
				foreach x of local liste {
					local liste2 G J
					foreach y of local liste2 {
						replace microbic_vente=microbic_vente+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
				local liste O 
				foreach x of local liste {
					local liste2 G 
					foreach y of local liste2 {
						replace microbic_vente_conj=microbic_vente_conj+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
				local liste P
				foreach x of local liste {
					local liste2 G 
					foreach y of local liste2 {
						replace microbic_vente_pac=microbic_vente_pac+Z5`x'`y' * (1-$tauxbic_vente)
					}
				}
			* Micro bic et autoentrepeneur : prestations de services
				local liste T 
				foreach x of local liste {
					local liste2 B
					foreach y of local liste2 {
						replace microbic_serv=microbic_serv+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
				local liste U 
				foreach x of local liste {
					local liste2 B
					foreach y of local liste2 {
						replace microbic_serv_conj=microbic_serv_conj+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
				local liste V
				foreach x of local liste {
					local liste2 B
					foreach y of local liste2 {
						replace microbic_serv_pac=microbic_serv_pac+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
								
				local liste K N
				foreach x of local liste {
					local liste2 P
					foreach y of local liste2 {
						replace microbic_serv=microbic_serv+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
				local liste L O 
				foreach x of local liste {
					local liste2 P
					foreach y of local liste2 {
						replace microbic_serv_conj=microbic_serv_conj+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
				local liste M P
				foreach x of local liste {
					local liste2 P
					foreach y of local liste2 {
						replace microbic_serv_pac=microbic_serv_pac+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
				
				local liste N 
				foreach x of local liste {
					local liste2 D
					foreach y of local liste2 {
						replace microbic_serv=microbic_serv+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
				local liste O 
				foreach x of local liste {
					local liste2 D
					foreach y of local liste2 {
						replace microbic_serv_conj=microbic_serv_conj+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
				local liste P
				foreach x of local liste {
					local liste2 D
					foreach y of local liste2 {
						replace microbic_serv_pac=microbic_serv_pac+Z5`x'`y' * (1-$tauxbic_serv)
					}
				}
			* Micro bnc et autoentrepeneur bnc
				local liste T
				foreach x of local liste {
					local liste2 E
					foreach y of local liste2 {
						replace microbnc=microbnc+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				local liste U 
				foreach x of local liste {
					local liste2 E
					foreach y of local liste2 {
						replace microbnc_conj=microbnc_conj+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				local liste V
				foreach x of local liste {
					local liste2 E
					foreach y of local liste2 {
						replace microbnc_pac=microbnc_pac+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				
				local liste H 
				foreach x of local liste {
					local liste2 Q
					foreach y of local liste2 {
						replace microbnc=microbnc+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				local liste I
				foreach x of local liste {
					local liste2 Q
					foreach y of local liste2 {
						replace microbnc_conj=microbnc_conj+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				local liste J
				foreach x of local liste {
					local liste2 Q
					foreach y of local liste2 {
						replace microbnc_pac=microbnc_pac+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				
				local liste K
				foreach x of local liste {
					local liste2 U
					foreach y of local liste2 {
						replace microbnc=microbnc+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				local liste L 
				foreach x of local liste {
					local liste2 U
					foreach y of local liste2 {
						replace microbnc_conj=microbnc_conj+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				local liste M
				foreach x of local liste {
					local liste2 U
					foreach y of local liste2 {
						replace microbnc_pac=microbnc_pac+Z5`x'`y' * (1-$tauxbnc)
					}
				}
				
			foreach var of varlist nonsal_irpp {
				replace `var'=`var'+microbnc+ microbic_serv+microbic_vente
				replace `var'_conj=`var'_conj+microbnc_conj+ microbic_serv_conj+microbic_vente_conj
				replace `var'_pac=`var'_pac+microbnc_pac+ microbic_serv_pac+microbic_vente_pac
			}
			foreach var of varlist nonsal {
				replace `var'=`var'_irpp+`var'exo_irpp
				replace `var'_conj=`var'_irpp_conj+`var'exo_irpp_conj
				replace `var'_pac=`var'_irpp_pac+`var'exo_irpp_pac
			}
							
			gen nonsal_irpp_foy=nonsal_irpp+nonsal_irpp_conj+nonsal_irpp_pac
			gen nonsalexo_irpp_foy=nonsalexo_irpp+nonsalexo_irpp_conj+nonsalexo_irpp_pac
			gen nonsal_foy=nonsal_irpp_foy+nonsalexo_irpp_foy
				
			
************************			
*IV)  Revenus fonciers
************************

		* A)Regime normal net de charges et intrts
		********************************************
			*en cas de benefices
				gen rfon_normal_irpp_foy=Z4BA
			* en cas de deficits: deficts catgoriels ou global
				gen rfon_defcat_foy= Z4BB
				gen rfon_defglo_foy=Z4BC
				
		* B) Regime micro-foncier brut
		******************************
			gen rfon_micro_irpp_foy= Z4BE*${tauxmicro_fon}
			gen rfon_irpp_foy=rfon_normal_irpp_foy+rfon_micro_irpp_foy
		

*****************
* V) Plus value		
******************

		gen rfin_pv_pro_irpp_foy=0
		gen rfin_mv_pro_irpp_foy=0
		gen rfin_pv_fon_irpp_foy=0
		gen rfin_pv_fin_irpp_foy=0
		gen rfin_mv_fin_irpp_foy=0
		gen rfin_pv_options_foy=0
		
		*A) Plus-values professionnelles
		********************************
		
			* Plus values	
				* Ajout PV declaration controle (conjoint+PAC) avant c'tait seulement total  partir rev 2005
				* Suppression distinction avec ou sans CGA pour PV  partir revenus 2007
				*Changement par rapport  2010: Introduction de TC UC VC : plus values provenant de la cession de brevet, licence d'exploitation
				
					local liste H I J
							foreach x of local liste {
								local liste2 W X E V R
								foreach y of local liste2 {
									replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+Z5`x'`y'
								
								}
							}
					
					local liste N O P
					foreach x of local liste {
						local liste2 X Q E
						foreach y of local liste2 {
							replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+Z5`x'`y'
						
						}
					}
					local liste  K L M
					foreach x of local liste {
						local liste2 X Q E Y V 
						foreach y of local liste2 {
							replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+Z5`x'`y'
						
						}
					}
					
					local liste  Q R S
					foreach x of local liste {
						local liste2 D
						foreach y of local liste2 {
							replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+Z5`x'`y'
						
						}
					}
					
										
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+Z5SO+ Z5TC
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+Z5NT+ Z5UC
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+Z5OT+ Z5VC

			* Moins-value
				* Pas de changement depuis 2005	
								
					local liste  K L M
					foreach x of local liste {
						local liste2 R W
						foreach y of local liste2 {
							replace rfin_mv_pro_irpp_foy=rfin_mv_pro_irpp_foy+Z5`x'`y'
						
						}
					}
					
					local liste   H I J
					foreach x of local liste {
						local liste2 S 
						foreach y of local liste2 {
							replace rfin_mv_pro_irpp_foy=rfin_mv_pro_irpp_foy+Z5`x'`y'
						
						}
					}
*nouveaut 2012 par rapport  2011: suppression de 5HU, mais il reste 5IU et 5JU
					replace rfin_mv_pro_irpp_foy=rfin_mv_pro_irpp_foy+Z5IU
					replace rfin_mv_pro_irpp_foy=rfin_mv_pro_irpp_foy+Z5JU
*nouveaut 2012 par rapport  2011: 5LZ et 5MZ
* et 5HU est supprime et remplac par 5KJ, 5LJ et 5MJ (moins values nettes a court terme individualisees)
					local liste   K L M
					foreach x of local liste {
						local liste2 J Z
						foreach y of local liste2 {
							replace rfin_mv_pro_irpp_foy=rfin_mv_pro_irpp_foy+Z5`x'`y'
						
						}
					}
					
					
					local liste   N O P
					foreach x of local liste {
						local liste2  R
						foreach y of local liste2 {
							replace rfin_mv_pro_irpp_foy=rfin_mv_pro_irpp_foy+Z5`x'`y'
						
						}
					}
					

			

		* B) Plus-values foncires	: rintroduction en 2012
		***************************
		replace rfin_pv_fon_irpp_foy=Z3VZ + Z3VW
	
		*C) Plus-values financires (on laisse de cote pv retraite dirigeant)
		***************************		
			*Changement par rapport  2011:
			*supppression 3VE
			*introduction de 3VT (clture PEA, gains taxables  30%, clture entre 2 et 5 ans --> Plus value tout comme 3VM l'tait)
			*introduction 3SA (plus value de cession de titres ralise par un entrepreneur, taxables  19%)
			*introduction de 3SJ SK : gains de cession de bons de souscription de parts de crateurs d'entreprise (--> plus values)
			*introduction de 1TT UT : gains de leve d'option  partir du 28.9.12 (--> stock option)
			*introduction de 3SD SI SF VK  : cases conjoint
			* VK change de nature (Cf. nv nature au-dessus)
			*introduction de 3VN,3SO,SS et SN : dj incluses dans d'autres variables
			local liste   V
						foreach x of local liste {
							local liste2  G L M C P Y
							foreach y of local liste2 {
								replace rfin_pv_fin_irpp_foy=rfin_pv_fin_irpp_foy+Z3`x'`y'							
							}
						}
						
			local liste  S
						foreach x of local liste {
							local liste2  A J K
							foreach y of local liste2 {
								replace rfin_pv_fin_irpp_foy=rfin_pv_fin_irpp_foy+Z3`x'`y'							
							}
						}
									
						
			replace rfin_mv_fin_irpp_foy=rfin_mv_fin_irpp_foy+Z3VH

			* Stock options : 
					local liste   T U
						foreach x of local liste {
							local liste2  V W X
							foreach y of local liste2 {
								replace rfin_pv_options_foy=rfin_pv_options_foy+Z1`x'`y'
							}
						}
					local liste   V
						foreach x of local liste {
							local liste2 J I F D
							foreach y of local liste2 {
								replace rfin_pv_options_foy=rfin_pv_options_foy+Z3`x'`y'
							
							}
						}	
					local liste   S
						foreach x of local liste {
							local liste2  D I F
							foreach y of local liste2 {
								replace rfin_pv_options_foy=rfin_pv_options_foy+Z3`x'`y'							
							}
						}		
			replace rfin_pv_options_foy=rfin_pv_options_foy+Z3VK
			
				gen rfin_pv_irpp_foy=rfin_pv_fin_irpp_foy+rfin_pv_fon_irpp_foy+rfin_pv_pro_irpp_foy+rfin_pv_options_foy
				gen rfin_mv_irpp_foy=rfin_mv_fin_irpp_foy+rfin_mv_pro_irpp_foy
***********************************************************************
keep year pondn-rfin_mv_irpp_foy
		drop micro* 
		gen idfoy=_n
		#delimit;
			order year idfoy pondn ndecl  age agec sexe mat npac  anaispac* 
			salchom* sal* chom* pens* rente* nonsal* nonsal_irpp* defnonsal_irpp* nonsalexo_irpp* rfon* 
			rfin_irpp_foy rfin_bar_irpp_foy rfin_pl_irpp_foy rfin_int_irpp_foy rfin_int_bar_irpp_foy rfin_int_pl_irpp_foy rfin_div_irpp_foy rfin_div_bar_irpp_foy rfin_div_pl_irpp_foy rfin_av_irpp_foy rfin_av_bar_irpp_foy rfin_av_pl_irpp_foy 
			rfin_pv_irpp_foy rfin_pv_pro_irpp_foy rfin_pv_fon_irpp_foy rfin_pv_fin_irpp_foy rfin_pv_options_foy rfin_mv_irpp_foy rfin_mv_pro_irpp_foy  rfin_mv_fin_irpp_foy ;
			 #delimit cr
		save "$wfrev/rev${year}.dta",replace
		
***************************************************************************************
