* Retraitement base fiscale 1996

set more off
clear

global year=1996

******************************************************************************************************************
* Legislative parameters converted in macro
		import excel using "$datarev/Parametres_IR.xls", first clear sheet("Parametres")  cellrange(A1:F20)
			foreach var of varlist tauxmicro_fon-tauxbnc{
				quiet sum `var' if year==$year
				global `var'=r(mean)
		}		
***************************************************************************************************************



use "$datarev/rev$year.dta",clear
gen year=$year


* Ponderation
	gen pondn=pond
	expand 10
	replace pondn=pondn/10

* Caractristiques dmographiques
	* age
		gen age=year-aged
		replace age=20 if age <20 | age==.
	* Nombre de dclarants dans la dclaration
		gen ndecl=2
		replace ndecl=1 if agec==9999
	* age du conjoint
		gen temp=year-agec if agec~=9999
		replace temp=20 if temp<20
		drop agec
		rename temp agec
	* sexe: Avant dernire lettre du fip 3= homme, 4 =femme
		gen sexe=.
	
	* Structure demo des pac : 1995 et 1996
		* Pour ces annes, les variables sont dj au format dsir
		local varlist = "age_enfant_01 age_enfant_02 age_enfant_03 age_enfant_04 age_enfant_05 age_enfant_06 age_enfant_07 age_enfant_08 age_enfant_09 age_enfant_10 age_enfant_11 age_enfant_12	"
		gen npac =0
		local i=0
		foreach var in `varlist'{
			local i=`i'+1
			replace npac=npac+1 if (`var' >0 & !missing(`var') )
			gen anaispac_`i'=`var' if (`var' >0 & !missing(`var') )	
		}
	
		/* verif
			quiet sum npac
			dis r(max)
			forval a=1/`r(max)' {
				sum anaispac_`a'
			}
			
		*/
		* Retraitement de l'anne de naissance vers age
			quiet sum npac
			forval a=1/`r(max)' {
				* Naissance arriv aprs l'anne de dclaration
					replace anaispac_`a'=year if anaispac_`a'~=. & anaispac_`a'>year
				* Il manque le 19 dans 19xx
				replace anaispac_`a'=anaispac_`a'+1900 if anaispac_`a'~=. & anaispac_`a'<100 & year-anaispac_`a'<2000
				* Il manque le 20 dans 20xx
				replace anaispac_`a'=anaispac_`a'+2000 if anaispac_`a'~=. & anaispac_`a'<100 & year-anaispac_`a'>=2000
				* Il manque le 1 dans 9xx
				replace anaispac_`a'=anaispac_`a'+1000 if anaispac_`a'~=. & anaispac_`a'<1000 & anaispac_`a'>800
				* Il manque le 9 dans 1xx
				replace anaispac_`a'=anaispac_`a'+1800 if anaispac_`a'~=. & anaispac_`a'<800 & anaispac_`a'>100
				replace anaispac_`a'=year-anaispac_`a' if anaispac_`a'~=. 
			}
					
			
	* situation matrimoniale : 
		* Code: 1= mari (M) ; 2 = clibataire (C), 3: Divorc (D),4: veuf (V), 6:pacs (O)
		* Avant 2002, le pacs n'existait pas
		gen temp="M" if mat==1
		replace temp="C" if mat==2
		replace temp="D" if mat==3
		replace temp="V" if mat==4
		drop mat
		rename temp mat
		
	
	* Impot pay
		gen irtot=F1P /* Impot immediat */
		gen irpv=ipp /* impot pv taux propor */
		gen iravantpv=irtot-irpv

	* Note: Attention: la base inclut les variables de la dclaration complmentaire et de la dclaration normale.

***********************************************************
*I)Traitements, salaires, pensions et rentes viagres  
***********************************************************

	foreach var of newlist sal_irpp chom_irpp frais_prof pension_irpp {
		gen `var'=0
		gen `var'_conj=0
		gen `var'_pac=0
	}

	* A) Salaires et chmages
	*************************
		* Pas de distinction entre sal et chom : on met tout dans sal et on utilisera seulement salchom
		* Remuneration des associs regroups dans les salaires AJ  partir de 1996

		replace sal_irpp=TS1AJ 
		replace chom_irpp=0

		replace sal_irpp_conj =  TS1BJ 
		replace chom_irpp_conj = 0
		
		* Frais pro
		replace frais_prof=TS1AK
		replace frais_prof_conj=TS1BK

	* B) Retraite
	**************
		* Inclue galement pensions alimentaires reues. Plus le cas  partir de 1999.
			replace pension_irpp=PR1AS
			replace pension_irpp_conj=PR1BS
			
	* C) Rentes viageres 
	**********************
		gen rente_irpp_foy=0
		local liste  A B C D
		foreach x of local liste {
				local liste2 U W Y
				foreach y of local liste2 {
					replace rente_irpp_foy= rente_irpp_foy+RV1`x'`y'
				}
		}

	* D)Personne  charge PAC
	****************************
		local liste C D E F
		foreach x of local liste {
			replace sal_irpp_pac= sal_irpp_pac + TS1`x'J  
			replace chom_irpp_pac= 0
			replace frais_prof_pac=frais_prof_pac + TS1`x'K
		}
		local liste C D R T
		foreach x of local liste {
			replace pension_irpp_pac= pension_irpp_pac+PR1`x'S
		}

		
	* E) Au niveau foyer fiscal
	****************************
		gen sal_irpp_foy=sal_irpp+sal_irpp_conj+sal_irpp_pac
		gen chom_irpp_foy=chom_irpp+chom_irpp_conj+chom_irpp_pac
		gen frais_prof_foy=frais_prof+frais_prof_conj+frais_prof_pac
		gen pension_irpp_foy =pension_irpp+ pension_irpp_conj +pension_irpp_pac
		gen salchom_irpp_foy=sal_irpp_foy+ chom_irpp_foy
		drop TS1A* TS1B* TS1C* TS1D* TS1E* TS1F* PR1?S  RV1*

	
	
**************************************	
*II)  Revenus des capitaux mobiliers
**************************************	
		* Changement de nom de variables par rapport a 97
		
		* A)Assurance-vie
		******************
			* Assurance-vie non declaree avant 1998
			* Bareme
				gen rfin_av_bar_irpp_foy = 0
			* PL
				gen rfin_av_pl_irpp_foy= 0
			* Total
				gen rfin_av_irpp_foy=rfin_av_bar_irpp_foy+rfin_av_pl_irpp_foy
		
		* B)Dividendes : 
		*****************
			* Au bareme 
				gen rfin_div_bar_irpp_foy = RC2CH 
				gen rfin_div_bar_irpp_foy2 = RC2CH + RC2LZ*((10546284259-1385428895)/10546284259)
			* Au PL a partir de 2008
				gen rfin_div_pl_irpp_foy=0
			* Total
				gen rfin_div_irpp_foy=rfin_div_pl_irpp_foy+rfin_div_bar_irpp_foy
				gen rfin_div_irpp_foy2=rfin_div_pl_irpp_foy+rfin_div_bar_irpp_foy2	
		
			
		* C)Interets 
		**************
			* Bareme
				gen rfin_int_bar_irpp_foy= RC2GR + RC2LZ+ RC2TR
				gen rfin_int_bar_irpp_foy2= RC2GR + RC2LZ*(1385428895/10546284259) + RC2TR
			* PL reporte seulement a partir de 2002
				gen rfin_int_pl_irpp_foy= 0
			* Total
				gen rfin_int_irpp_foy= rfin_int_bar_irpp_foy+ rfin_int_pl_irpp_foy
				gen rfin_int_irpp_foy2= rfin_int_bar_irpp_foy2+ rfin_int_pl_irpp_foy
		
		* D) Totaux 
		**************
				gen rfin_pl_irpp_foy=rfin_av_pl_irpp_foy+rfin_div_pl_irpp_foy+rfin_int_pl_irpp_foy
				gen rfin_bar_irpp_foy=rfin_av_bar_irpp_foy+rfin_div_bar_irpp_foy+rfin_int_bar_irpp_foy
				gen rfin_irpp_foy=rfin_av_irpp_foy+rfin_div_irpp_foy+rfin_int_irpp_foy
		
		* Note: Avant 2005, on remboursait l'IS preleve sur les dividendes via un avoir fiscal pour viter double imposition.
			* Systeme a change en 2005 en creant un abattement remplacant l'avoir fiscal
			drop RC2*

*******************************
*III) Revenus non salaries
*******************************

	foreach var of newlist nonsal_irpp nonsalexo_irpp nonsal defnonsal_irpp microbic_vente microbic_serv microbnc {
		gen `var'=0
		gen `var'_conj=0
		gen `var'_pac=0
	}
		* A) Revenus non salaris exos
		*******************************
			*Pas de revenus exonrs. Date de 1997 avec creation des zones franches urbaines
				
		* B)Revenus non salaris: benefice
		**************************************
			* On rajoute 25% pour centre non agr
			
			replace nonsal_irpp=nonsal_irpp+ALNP5GL if ndecl==1
			replace nonsal_irpp=nonsal_irpp+0.5*ALNP5GL if ndecl==2
			replace nonsal_irpp_conj=nonsal_irpp_conj+0.5*ALNP5GL if ndecl==2
			
			replace nonsal_irpp=nonsal_irpp+LMR5GJ if ndecl==1
			replace nonsal_irpp=nonsal_irpp+0.5*LMR5GJ if ndecl==2
			replace nonsal_irpp_conj=nonsal_irpp_conj+0.5*LMR5GJ if ndecl==2
		
			local liste F 
			foreach x of local liste {
				local liste2 S T
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+BA5`x'`y'*1.25
				
				}
			}
			local liste G 
			foreach x of local liste {
				local liste2 S T
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+BA5`x'`y'*1.25
				
				}
			}
			local liste H 
			foreach x of local liste {
				local liste2 S T
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+BA5`x'`y'*1.25
				
				}
			}
						
			local liste J 
			foreach x of local liste {
				local liste2 A B
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+BA5`x'`y'
				
				}
			local liste K 
			foreach x of local liste {
				local liste2 A B
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+BA5`x'`y'
				
				}
			}
			local liste L
			foreach x of local liste {
				local liste2 A B
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+BA5`x'`y'
				
				}
			}
			}
			
			
			local liste J 
			foreach x of local liste {
				local liste2 S T
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+BIC5`x'`y'*1.25
				
				}
			}
			local liste K 
			foreach x of local liste {
				local liste2 S T
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+BIC5`x'`y'*1.25
				
				}
			}
			local liste L
			foreach x of local liste {
				local liste2 S T
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+BIC5`x'`y'*1.25
				
				}
			}
		
			local liste  M 
			foreach x of local liste {
				local liste2 A B 
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+BIC5`x'`y'
				
				}
			}
			local liste  N
			foreach x of local liste {
				local liste2 A B 
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+BIC5`x'`y'
				
				}
			}
			local liste  P
			foreach x of local liste {
				local liste2 A B 
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+BIC5`x'`y'
				
				}
			}
			
			local liste  M 
			foreach x of local liste {
				local liste2 S 
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+BNC5`x'`y'*1.25
				
				}
			}
			local liste  N 
			foreach x of local liste {
				local liste2 S 
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+BNC5`x'`y'*1.25
				
				}
			}
			local liste  P
			foreach x of local liste {
				local liste2 S 
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+BNC5`x'`y'*1.25
				
				}
			}
			
			local liste  R
			foreach x of local liste {
				local liste2 H 
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+BA5`x'`y'
				}
				local liste2 J
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+BIC5`x'`y'
				}
				local liste2 K A
				foreach y of local liste2 {
					replace nonsal_irpp=nonsal_irpp+BNC5`x'`y'
				}
			}
			local liste  S 
			foreach x of local liste {
				local liste2 H 
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+BA5`x'`y'
				}
				local liste2 J
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+BIC5`x'`y'
				}
				local liste2 K A
				foreach y of local liste2 {
					replace nonsal_irpp_conj=nonsal_irpp_conj+BNC5`x'`y'
				}
			}
			local liste  T
			foreach x of local liste {
				local liste2 H 
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+BA5`x'`y'
				}
				local liste2 J
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+BIC5`x'`y'
				}
				local liste2 K A
				foreach y of local liste2 {
					replace nonsal_irpp_pac=nonsal_irpp_pac+BNC5`x'`y'
				}
			}
	
			
		* C) Revenus non salairs: plus-values voir section plus-value rfin_pv_pro_irpp_foy
		***************************************************************************************	

		* D)Revenus non salaris: dficits
		***********************************
			local liste F 
			foreach x of local liste {
				local liste2 W 
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+BA5`x'`y'
				}
			}
			local liste G
			foreach x of local liste {
				local liste2 W 
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+BA5`x'`y'
				}
			}
			local liste H
			foreach x of local liste {
				local liste2 W 
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+BA5`x'`y'
				}
			}
									
			local liste J
			foreach x of local liste {
				local liste2 E
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+BA5`x'`y'
				}
			}			
			local liste K 
			foreach x of local liste {
				local liste2 E
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+BA5`x'`y'
				}
			}			
			local liste L
			foreach x of local liste {
				local liste2 E
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+BA5`x'`y'
				}
			}
		
			local liste J
			foreach x of local liste {
				local liste2 W X 
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+BIC5`x'`y'
				}
			}
			local liste K 
			foreach x of local liste {
				local liste2 W X 
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+BIC5`x'`y'
				}
			}
			local liste L
			foreach x of local liste {
				local liste2 W X 
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+BIC5`x'`y'
				}
			}
			
			local liste M 
			foreach x of local liste {
				local liste2 E F
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+BIC5`x'`y'
				}
			}
			local liste N 
			foreach x of local liste {
				local liste2 E F
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+BIC5`x'`y'
				}
			}
			local liste P
			foreach x of local liste {
				local liste2 E F
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+BIC5`x'`y'
				}
			}
						
			local liste M 
			foreach x of local liste {
				local liste2 V
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+BNC5`x'`y'
				}
			}
			local liste N 
			foreach x of local liste {
				local liste2 V
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+BNC5`x'`y'
				}
			}
			local liste P
			foreach x of local liste {
				local liste2 V
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+BNC5`x'`y'
				}
			}
						
			local liste R
			foreach x of local liste {
				local liste2 D
				foreach y of local liste2 {
					replace defnonsal_irpp=defnonsal_irpp+BNC5`x'`y'
				}
			}			
			local liste S
			foreach x of local liste {
				local liste2 D
				foreach y of local liste2 {
					replace defnonsal_irpp_conj=defnonsal_irpp_conj+BNC5`x'`y'
				}
			}			
			local liste T
			foreach x of local liste {
				local liste2 D
				foreach y of local liste2 {
					replace defnonsal_irpp_pac=defnonsal_irpp_pac+BNC5`x'`y'
				}
			}
			
			replace defnonsal_irpp=defnonsal_irpp+ALNP5HL if ndecl==1
			replace defnonsal_irpp=defnonsal_irpp+0.5*ALNP5HL if ndecl==2
			replace defnonsal_irpp_conj=defnonsal_irpp_conj+0.5*ALNP5HL if ndecl==2
						
			replace defnonsal_irpp=defnonsal_irpp+LMR5HJ if ndecl==1
			replace defnonsal_irpp=defnonsal_irpp+0.5*LMR5HJ if ndecl==2
			replace defnonsal_irpp_conj=defnonsal_irpp_conj+0.5*LMR5HJ if ndecl==2
					
		* E)Revenus non salaris: micro-fonciers et auto-entrepreneurs
		*************************************************************	
		* Recalcul du bnfice pour les auto-entrepreneurs et le rgime micro-entreprise (il faut dduire un abattement du chiffre d'affaire dclar pour retrouver le bnfice rel)
		* Les activits accessoires (tourisme et travaux forestiers) beneficient d'un abattement de 50% de 1996  1998 (checker avant). On les considre donc comme des micro bic (meme abattement)
	
			* Micro bic et autoentrepeneur : vente de marchandises
				* Avant 1999, pas de distinction entre BIC ventes de march et prest de services pour l'abattement
				local liste R 
				foreach x of local liste {
					local liste2 L M
					foreach y of local liste2 {
						replace microbic_vente=microbic_vente+BIC5`x'`y' * (1-$tauxbic_vente)
					}
				}
				local liste S 
				foreach x of local liste {
					local liste2 L M
					foreach y of local liste2 {
						replace microbic_vente_conj=microbic_vente_conj+BIC5`x'`y' * (1-$tauxbic_vente)
					}
				}
				local liste T 
				foreach x of local liste {
					local liste2 L M
					foreach y of local liste2 {
						replace microbic_vente_pac=microbic_vente_pac+BIC5`x'`y' * (1-$tauxbic_vente)
					}
				}
								
				local liste R 
				foreach x of local liste {
					local liste2 P
					foreach y of local liste2 {
						replace microbic_vente=microbic_vente+BA5`x'`y' * (1-$tauxbic_vente)
					}
				}				
				local liste S  
				foreach x of local liste {
					local liste2 P
					foreach y of local liste2 {
						replace microbic_vente_conj=microbic_vente_conj+BA5`x'`y' * (1-$tauxbic_vente)
					}
				}				
				local liste T 
				foreach x of local liste {
					local liste2 P
					foreach y of local liste2 {
						replace microbic_vente_pac=microbic_vente_pac+BA5`x'`y' * (1-$tauxbic_vente)
					}
				}

				
			* Micro bic et autoentrepeneur : 
				* Inclus dans microbic_vente avant 1999
				
			* Micro bnc et autoentrepeneur bnc
				local liste R 
				foreach x of local liste {
					local liste2 N 
					foreach y of local liste2 {
						replace microbnc=microbnc+BNC5`x'`y' * (1-$tauxbnc)
					}
				}
				local liste S 
				foreach x of local liste {
					local liste2 N 
					foreach y of local liste2 {
						replace microbnc_conj=microbnc_conj+BNC5`x'`y' * (1-$tauxbnc)
					}
				}
				local liste T
				foreach x of local liste {
					local liste2 N 
					foreach y of local liste2 {
						replace microbnc_pac=microbnc_pac+BNC5`x'`y' * (1-$tauxbnc)
					}
				}
							
			foreach var of varlist nonsal_irpp {
				replace `var'=`var'+microbnc+ microbic_serv+microbic_vente
				replace `var'_conj=`var'_conj+microbnc_conj+ microbic_serv_conj+microbic_vente_conj
				replace `var'_pac=`var'_pac+microbnc_pac+ microbic_serv_pac+microbic_vente_pac
			}
			foreach var of varlist nonsal {
				replace `var'=`var'_irpp+`var'exo_irpp
				replace `var'_conj=`var'_irpp_conj+`var'exo_irpp_conj
				replace `var'_pac=`var'_irpp_pac+`var'exo_irpp_pac
			}
							
			gen nonsal_irpp_foy=nonsal_irpp+nonsal_irpp_conj+nonsal_irpp_pac
			gen nonsalexo_irpp_foy=nonsalexo_irpp+nonsalexo_irpp_conj+nonsalexo_irpp_pac
			gen nonsal_foy=nonsal_irpp_foy+nonsalexo_irpp_foy
			
									
************************			
*IV)  Revenus fonciers
************************

		* A)Regime normal net de charges et intrts
		********************************************
			*en cas de benefices
				gen rfon_normal_irpp_foy=RF4CD
			* en cas de deficits: deficts catgoriels ou global
				gen rfon_defcat_foy= RF4CE
				gen rfon_defglo_foy=RF4CF
				
		* B) Regime micro-foncier brut
		******************************
			*Cr en 1997
			gen rfon_micro_irpp_foy=0
		
		gen rfon_irpp_foy=rfon_normal_irpp_foy+rfon_micro_irpp_foy
		drop RF4*

*****************
* V) Plus value		
******************

		gen rfin_pv_pro_irpp_foy=0
		gen rfin_mv_pro_irpp_foy=0
		gen rfin_pv_fon_irpp_foy=0
		gen rfin_pv_fin_irpp_foy=0
		gen rfin_mv_fin_irpp_foy=0
		gen rfin_pv_options_foy=0
		
		*A) Plus-values professionnelles
		********************************
			replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+LMR5GK
			replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+ALNP5GM
			replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+PV3VG /* Cession socit soumise  l'IR*/

			local liste F G H
			foreach x of local liste {
				local liste2 U
				foreach y of local liste2 {
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+BA5`x'`y'
				}
			}
			local liste J K L
			foreach x of local liste {
				local liste2 U
				foreach y of local liste2 {
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+BIC5`x'`y'
				}
			}
			local liste J K L
			foreach x of local liste {
				local liste2 C
				foreach y of local liste2 {
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+BA5`x'`y'
				}
			}
			local liste M N P
			foreach x of local liste {
				local liste2 T
				foreach y of local liste2 {
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+BNC5`x'`y'
				}
			}
			local liste M N P
			foreach x of local liste {
				local liste2 C
				foreach y of local liste2 {
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+BIC5`x'`y'
				}
			}
			local liste  R S T
			foreach x of local liste {
				local liste2 B
				foreach y of local liste2 {
					replace rfin_pv_pro_irpp_foy=rfin_pv_pro_irpp_foy+BNC5`x'`y'
				
				}
			}
			
	
		* B) Plus-values foncires	
		***************************
			replace rfin_pv_fon_irpp_foy=PV3VD+PV3VE+PV3VF
	
		*C) Plus-values financires
		***************************
* Disparition de 3VS (modif par rapport  1995)
			* Regime normal + pv de PEA clotur avant 2 ans + pv capital risque 
				local liste   V
				foreach x of local liste {
					local liste2  H K N P
					foreach y of local liste2 {
						replace rfin_pv_fin_irpp_foy=rfin_pv_fin_irpp_foy+PV3`x'`y'
					}
					local liste2  J L
					foreach y of local liste2 {
						replace rfin_mv_fin_irpp_foy=rfin_mv_fin_irpp_foy+PV3`x'`y'
					}
				}
			* Stock options :
				local liste   T U
				foreach x of local liste {
					local liste2  V W X Y
					foreach y of local liste2 {
						replace rfin_pv_options_foy=rfin_pv_options_foy+TS1`x'`y'
					}
				}
				
			gen rfin_pv_irpp_foy=rfin_pv_fin_irpp_foy+rfin_pv_fon_irpp_foy+rfin_pv_pro_irpp_foy+rfin_pv_options_foy
			gen rfin_mv_irpp_foy=rfin_mv_fin_irpp_foy+rfin_mv_pro_irpp_foy		
			drop PV3*
	
***************************************************************************************
	keep year pondn-rfin_mv_irpp_foy
		drop micro* 
		gen idfoy=_n
		#delimit;
			order year idfoy pondn ndecl  age agec sexe mat  npac  anaispac* 
			salchom* sal* chom* pens* rente* nonsal* nonsal_irpp* defnonsal_irpp* nonsalexo_irpp* rfon* 
			rfin_irpp_foy rfin_bar_irpp_foy rfin_pl_irpp_foy rfin_int_irpp_foy rfin_int_irpp_foy2 rfin_int_bar_irpp_foy rfin_int_bar_irpp_foy2 rfin_int_pl_irpp_foy rfin_div_irpp_foy rfin_div_irpp_foy2 rfin_div_bar_irpp_foy rfin_div_bar_irpp_foy2 rfin_div_pl_irpp_foy rfin_av_irpp_foy rfin_av_bar_irpp_foy rfin_av_pl_irpp_foy 
			rfin_pv_irpp_foy rfin_pv_pro_irpp_foy rfin_pv_fon_irpp_foy rfin_pv_fin_irpp_foy rfin_pv_options_foy rfin_mv_irpp_foy rfin_mv_pro_irpp_foy  rfin_mv_fin_irpp_foy ;
			#delimit cr
		save "$wfrev/rev${year}.dta",replace
		
	
